@@ -10,7 +10,7 @@ use IO::Compress::Gzip  2.008 ();
 use IO::Compress::Bzip2 2.008 ();
 use Xtract::LZMA              ();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Moose 0.73;
 
@@ -31,7 +31,7 @@ sub flag ($$) {
 	has $_[0] => (
 		is       => 'ro',
 		isa      => 'Bool',
-		requires => 1,
+		required => 1,
 		default  => $_[1],
 	);
 }
